import sys
import traceback

from lumos.cli import cli


def main(argv=None):
    """Main entry point"""

    if argv==None:
        argv = sys.argv

    try:
        return cli(argv[1:])
    except KeyboardInterrupt:
        print("Aborted by user")
    except Exception as e:
        print("FATAL: ", repr(e))
        print(traceback.format_exc())
        sys.exit(1)


if __name__ == '__main__':
    sys.exit(main())
    



from setuptools import setup, find_packages

setup(
    name='pylumos',
    version="0.0.1",
    packages=find_packages(),
    setup_requires=['setuptools_scm'],
    license='MIT',
    author='Adrian Rothenbuhler',
    author_email='adrian@redhill-embedded.com',
    description='Addressable LED interface tool',
    keywords='LED',
    url='https://github.com/redhill-embedded/recom.git',
    #download_url='https://github.com/redhill-embedded/lumos/archive/v_010.tar.gz',
    package_data={
        "lumos": [
            "package_version"
        ]
    },
    python_requires=">=3.8",
    install_requires=["recom"],
    entry_points={
        "console_scripts": [
            "lumos=lumos.__main__:main",
        ]
    },
)